==> nodejs_interop-0.7.0.tar.gz: lib/src/node/url/url_module.dart <==
part of nodejs_interop.node;
// ignore_for_file: avoid_positional_boolean_parameters

/// Provides options for serializing a URL object into a string.
@JS()
@anonymous
class FormatOptions {

  /// Creates a new options object.
  external factory FormatOptions({
    bool auth = true,
    bool fragment = true,
    bool search = true,
    bool unicode = false
  });

  /// Value indicating whether the serialized URL string should include the username and password.
  external bool get auth;
  external set auth(bool value);

  /// Value indicating whether the serialized URL string should include the fragment.
  external bool get fragment;
  external set fragment(bool value);

  /// Value indicating whether the serialized URL string should include the search query.
  external bool get search;
  external set search(bool value);

  /// Value indicating whether Unicode characters appearing in the host component of the URL string
  /// should be encoded directly as opposed to being [Punycode](https://tools.ietf.org/html/rfc3492) encoded.
  external bool get unicode;
  external set unicode(bool value);
}

/// The [`url`](https://nodejs.org/api/url.html) module.
@JS()
abstract class UrlModule {

  /// Returns the [Punycode](https://tools.ietf.org/html/rfc3492) ASCII serialization of the [domain].
  /// If [domain] is an invalid domain, the empty string is returned.
  external String domainToASCII(String domain);

  /// Returns the Unicode serialization of the [domain].
  /// If [domain] is an invalid domain, the empty string is returned.
  external String domainToUnicode(String domain);

  /// Returns a formatted URL string derived from the specified [urlObject].
  external String format(urlObject, [FormatOptions options]);

  /// Takes a URL string, parses it, and returns a URL object.
  ///
  /// If [parseQueryString] is `true`, the query property will always be set to an object returned by the [QueryStringModule.parse] method.
  /// If [slashesDenoteHost] is `true`, the first token after the literal string `//` and preceding the next `/` will be interpreted as the [UrlObject.host].
  external UrlObject parse(String urlString, [bool parseQueryString = false, bool slashesDenoteHost = false]);

  /// Resolves a target URL relative to a base URL in a manner similar to that of a Web browser resolving an anchor tag `href`.
  external String resolve(String from, String to);
}

==> nodejs_interop-0.8.0.tar.gz: lib/src/node/url/url_module.dart <==
part of nodejs_interop.node;

/// Provides options for serializing a URL object into a string.
@JS()
@anonymous
class FormatOptions {

  /// Creates a new options object.
  external factory FormatOptions({
    bool auth = true,
    bool fragment = true,
    bool search = true,
    bool unicode = false
  });

  /// Value indicating whether the serialized URL string should include the username and password.
  external bool get auth;
  external set auth(bool value);

  /// Value indicating whether the serialized URL string should include the fragment.
  external bool get fragment;
  external set fragment(bool value);

  /// Value indicating whether the serialized URL string should include the search query.
  external bool get search;
  external set search(bool value);

  /// Value indicating whether Unicode characters appearing in the host component of the URL string
  /// should be encoded directly as opposed to being [Punycode](https://tools.ietf.org/html/rfc3492) encoded.
  external bool get unicode;
  external set unicode(bool value);
}

/// The [`url`](https://nodejs.org/api/url.html) module.
@JS()
abstract class UrlModule {

  /// Returns the [Punycode](https://tools.ietf.org/html/rfc3492) ASCII serialization of the [domain].
  /// If [domain] is an invalid domain, the empty string is returned.
  external String domainToASCII(String domain);

  /// Returns the Unicode serialization of the [domain].
  /// If [domain] is an invalid domain, the empty string is returned.
  external String domainToUnicode(String domain);

  /// Returns a formatted URL string derived from the specified [urlObject].
  external String format(urlObject, [FormatOptions options]);

  /// Takes a URL string, parses it, and returns a URL object.
  ///
  /// If [parseQueryString] is `true`, the query property will always be set to an object returned by the [QueryStringModule.parse] method.
  /// If [slashesDenoteHost] is `true`, the first token after the literal string `//` and preceding the next `/` will be interpreted as the [UrlObject.host].
  external UrlObject parse(String urlString, [bool parseQueryString = false, bool slashesDenoteHost = false]); // ignore: avoid_positional_boolean_parameters

  /// Resolves a target URL relative to a base URL in a manner similar to that of a Web browser resolving an anchor tag `href`.
  external String resolve(String from, String to);
}
